# tldraw_jupyter_experiment

![Binder](https://mybinder.org/v2/gh/kolibril13/jupyter-tldraw/HEAD?labpath=debugging_notebooks%tldraw_shape2_example.ipynb)

Annotating jupyter cell output with tldraw

Demo how this might look like one day:

https://user-images.githubusercontent.com/44469195/224175450-d91bf5b9-c442-4103-a680-3a9a191b0f93.mov


Installation:
```
python3.11 -m venv .venv
pip install jupyterlab
pip install ipyreact
jupyterlab   (or alternative VS Code Jupyter Lab)
```